aboutsummaryrefslogtreecommitdiffstats
path: root/Alc/mixer.c
diff options
context:
space:
mode:
authorChris Robinson <[email protected]>2017-12-29 16:28:49 -0800
committerChris Robinson <[email protected]>2017-12-29 16:28:49 -0800
commit98731bb574c77b291f86195a2c2fb1f6d00fe7a4 (patch)
tree3b7ed6a8c4b269c4fd8c647ac32fbfbc0b28f595 /Alc/mixer.c
parent27dfb7fd11ae290956fd7af631baab076d8e83a7 (diff)
Update resampler padding checks
Diffstat (limited to 'Alc/mixer.c')
-rw-r--r--Alc/mixer.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/Alc/mixer.c b/Alc/mixer.c
index 00d2c601..bbbfba18 100644
--- a/Alc/mixer.c
+++ b/Alc/mixer.c
@@ -44,9 +44,9 @@ static_assert((INT_MAX>>FRACTIONBITS)/MAX_PITCH > BUFFERSIZE,
extern inline void InitiatePositionArrays(ALsizei frac, ALint increment, ALsizei *restrict frac_arr, ALint *restrict pos_arr, ALsizei size);
-/* BSinc requires up to 11 extra samples before the current position, and 12 after. */
-static_assert(MAX_PRE_SAMPLES >= 11, "MAX_PRE_SAMPLES must be at least 11!");
-static_assert(MAX_POST_SAMPLES >= 12, "MAX_POST_SAMPLES must be at least 12!");
+/* BSinc24 requires up to 23 extra samples before the current position, and 24 after. */
+static_assert(MAX_PRE_SAMPLES >= 23, "MAX_PRE_SAMPLES must be at least 23!");
+static_assert(MAX_POST_SAMPLES >= 24, "MAX_POST_SAMPLES must be at least 24!");
enum Resampler ResamplerDefault = LinearResampler;